@@ -106,7 +106,7 @@ import os
 import sys
 
 import ${NAME}.app
-from ${NAME}.config import getConfig
+from freenit.config import getConfig
 from alembic import context
 from freenit.migration import run_migrations_offline, run_migrations_online
 
